# Description

This project is an adaptation from the work of Hans Bruun Nielsen, Søren Nymand and Lophaven Jacob Søndergaard.

## Notes
**This is a implementation that relies heavily on linear algebra solvers** (least-squares solvers, Cholesky and QR 
decompositions, etc.). Therefore is strongly advised that your numpy library be integrated to a 
[BLAS library](http://markus-beuckelmann.de/blog/boosting-numpy-blas.html) (e.g.: Intel-MKL, OpenBLAS, ATLAS, etc.) 
in order to attain satisfactory performances of calculation.

For the sake of convenience, Anaconda handles the gritty details of how to combine numpy and those libraries natively.

## Installation

To install through PyPi Repository:

    pip install pydacefit

To install via conda

    conda install -c conda-forge pydace
    
## Usage

In progress...

## Contact/Talk to me

My e-emal is felipe.lima@eq.ufcg.edu.br. Feel free to contact me anytime.